==> twinlisp-0.1.2.tar.gz: twinlisp/tests/test-core/_load_.lisp <==
;Copyright (C) 2006 Mikalai Birukou
;
;This file is part of TwinLisp.
;
;    TwinLisp is free software; you can redistribute it and/or modify
;    it under the terms of the GNU General Public License as published by
;    the Free Software Foundation; either version 2 of the License, or
;    (at your option) any later version.
;
;    TwinLisp is distributed in the hope that it will be useful,
;    but WITHOUT ANY WARRANTY; without even the implied warranty of
;    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;    GNU General Public License for more details.
;
;    You should have received a copy of the GNU General Public License
;    along with TwinLisp; if not, write to the Free Software
;    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
(tl-require "unittest")
(_<<_ (_<<_ (_<<_ (cout) #\Newline) "Testing TwinLisp's core components:") #\Newline)
; testcases defined in the current pack
(tl-require "TestOperMeths")
(tl-require "TestContainerMeths")
(tl-require "TestOtherMacs")
; testcases defined in TwinLisp pack
(tl-require "TestTranslStringReading")
(tl-require "TestTranslElemSearchFuncs")
(tl-require "TestTranslFormBuilding")
(tl-require "TestTranslFormBuildingTwo")
(tl-require "TestTranslFormBuildingThree")
(tl-require "TestTranslFormWritting")
; this will let us reach tests defined in TwinLisp pack
(unittest:runSuites '(TestOperMeths TestContainerMeths TestOtherMacs TWINLISP::TestTranslStringReading TWINLISP::TestTranslElemSearchFuncs TWINLISP::TestTranslFormBuilding TWINLISP::TestTranslFormBuildingTwo TWINLISP::TestTranslFormBuildingThree TWINLISP::TestTranslFormWritting) :verbosity 1)

==> twinlisp-0.5.tar.gz: twinlisp/tests/test-core/_load_.lisp <==
;Copyright (C) 2006 Mikalai Birukou
;
;This file is part of TwinLisp.
;
;    TwinLisp is free software; you can redistribute it and/or modify
;    it under the terms of the GNU General Public License as published by
;    the Free Software Foundation; either version 2 of the License, or
;    (at your option) any later version.
;
;    TwinLisp is distributed in the hope that it will be useful,
;    but WITHOUT ANY WARRANTY; without even the implied warranty of
;    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;    GNU General Public License for more details.
;
;    You should have received a copy of the GNU General Public License
;    along with TwinLisp; if not, write to the Free Software
;    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
(tl-require "unittest")
(_<<_ (_<<_ (_<<_ (cout) #\Newline) "Testing TwinLisp's core components:") #\Newline)
; testcases defined in the current pack
(tl-require "TestOperMeths")
(tl-require "TestContainerMeths")
(tl-require "TestOtherMacs")
; testcases defined in TwinLisp pack
(tl-require "TestTranslStringReading")
(tl-require "TestTranslElemSearchFuncs")
(tl-require "TestTranslFormBuilding")
(tl-require "TestTranslFormBuildingTwo")
(tl-require "TestTranslFormBuildingThree")
(tl-require "TestTranslFormBuildingFour")
(tl-require "TestTranslFormWritting")
; this will let us reach tests defined in TwinLisp pack
(unittest:runSuites '(TestOperMeths TestContainerMeths TestOtherMacs TWINLISP::TestTranslStringReading TWINLISP::TestTranslElemSearchFuncs TWINLISP::TestTranslFormBuilding TWINLISP::TestTranslFormBuildingTwo TWINLISP::TestTranslFormBuildingThree TWINLISP::TestTranslFormBuildingFour TWINLISP::TestTranslFormWritting) :verbosity 1)
